@@ -1,4 +1,4 @@
-use crate::token::{ ParserToken };
+use crate::token::ParserToken;
 use bincode;
 
 pub fn to_bytecode(parsed: Vec<ParserToken>) -> Vec<u8> {
@@ -8,4 +8,3 @@ pub fn to_bytecode(parsed: Vec<ParserToken>) -> Vec<u8> {
 pub fn from_bytecode(bytecode: &[u8]) -> Vec<ParserToken> {
     bincode::deserialize(bytecode).unwrap()
 }
-
